unit Accolade;

interface

uses Messages, Windows, SysUtils, Classes, Controls, Forms, Menus, Graphics,
  StdCtrls;

Type
  TAOrientation = (aoGaucheADroite, aoDroiteAGauche, aoHautEnBas, aoBasEnHaut);


  TAccolade = class(TGraphicControl)
  private
    FOrientation : TAOrientation;
    FEpaisseur : integer;
    procedure SetOrientation(Value: TAOrientation);
    Procedure SetEpaisseur(Value : Integer);
  protected
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
  published
    property Orientation :TAOrientation read FOrientation write SetOrientation;
    property Epaisseur : integer read FEpaisseur write SetEpaisseur;
    property Align;
    property Anchors;
    property Color default ClBlack;
    property Constraints;
    property DragKind;
    property DragMode;
    property ParentShowHint;
    property ShowHint;
    property Visible;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
  end;


procedure Register;

implementation


procedure Register;
begin
  RegisterComponents('Exemples', [TAccolade]);
end;


constructor TAccolade.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle + [csReplicatable];
  Width := 50;
  Height := 50;
  Color:=ClBlack;
end;


procedure TAccolade.Paint;
begin
  with Canvas do begin
    if (csDesigning in ComponentState) then begin
        Pen.Style := psSolid;
        Pen.Mode  := pmCopy;
        Pen.Color := clBlack;
        Brush.Style := bsSolid;
    end;

    Pen.Width := FEpaisseur;
    pen.Color:=Color;
    case FOrientation of
         aoGaucheADroite: begin
             Arc( 0, 0, round(2*Width/4), round(2*Height/10),
             round(2*Width/4), round(Height/10), round(Width/4), 0);
             MoveTo(round(2*Width/4), round(Height/10)-1);
             LineTo(round(2*Width/4), round(4*Height/10)+1);
             Arc( round(2*Width/4), round(3*Height/10), Width, round(5*Height/10),
                  round(2*Width/4), round(4*Height/10), round(3*Width/4), round(5*Height/10));
             Arc( round(2*Width/4), round(5*Height/10), Width, round(7*Height/10),
                  round(3*Width/4), round(5*Height/10), round(2*Width/4), round(6*Height/10));
             MoveTo(round(2*Width/4), round(6*Height/10)-1);
             LineTo(round(2*Width/4), round(9*Height/10)+1);
             Arc( 0, round(8*Height/10), round(2*Width/4), Height,
                  round(Width/4), Height, round(2*Width/4), round(9*Height/10));
         end;
         aoDroiteAGauche : begin
             Arc( round(2*Width/4), 0, round(4*Width/4), round(2*Height/10),
             round(3*Width/4), round(0*Height/10), round(2*Width/4), round(1*Height/10));
             MoveTo(round(2*Width/4), round(Height/10)-1);
             LineTo(round(2*Width/4), round(4*Height/10)+1);
             Arc( round(0*Width/4), round(3*Height/10), round(2*Width/4), round(5*Height/10),
                  round(1*Width/4), round(5*Height/10), round(2*Width/4), round(4*Height/10));
             Arc( round(0*Width/4), round(5*Height/10), round(2*Width/4), round(7*Height/10),
                  round(2*Width/4), round(6*Height/10), round(1*Width/4), round(5*Height/10));
             MoveTo(round(2*Width/4), round(6*Height/10)-1);
             LineTo(round(2*Width/4), round(9*Height/10)+1);
             Arc( round(2*Width/4), round(8*Height/10), round(4*Width/4), Height,
                  round(2*Width/4), round(9*Height/10), round(3*Width/4), round(10*Height/10));
         end;
         aoHautEnBas : begin
             Arc( round(0*Width/10), 0, round(2*Width/10), round(2*Height/4),
             round(0*Width/10), round(1*Height/4), round(1*Width/10), round(2*Height/4));
             MoveTo(round(1*Width/10)-1, round(2*Height/4));
             LineTo(round(4*Width/10)+1, round(2*Height/4));
             Arc( round(3*Width/10), round(2*Height/4), round(5*Width/10), round(4*Height/4),
                  round(5*Width/10), round(3*Height/4), round(4*Width/10), round(2*Height/4));
             Arc( round(5*Width/10), round(2*Height/4), round(7*Width/10), round(4*Height/4),
                  round(6*Width/10), round(2*Height/4), round(5*Width/10), round(3*Height/4));
             MoveTo(round(6*Width/10)-1, round(2*Height/4));
             LineTo(round(9*Width/10)+1, round(2*Height/4));
             Arc( round(8*Width/10), round(0*Height/4), round(10*Width/10), round(2*Height/4),
                  round(9*Width/10), round(2*Height/4), round(10*Width/10), round(1*Height/4));
         end;
         aoBasEnHaut : begin
             Arc( round(0*Width/10), round(2*Height/4), round(2*Width/10), round(4*Height/4),
             round(1*Width/10), round(2*Height/4), round(0*Width/10), round(3*Height/4));
             MoveTo(round(1*Width/10)-1, round(2*Height/4));
             LineTo(round(4*Width/10)+1, round(2*Height/4));
             Arc( round(3*Width/10), round(0*Height/4), round(5*Width/10), round(2*Height/4),
                  round(4*Width/10), round(2*Height/4), round(5*Width/10), round(1*Height/4));
             Arc( round(5*Width/10), round(0*Height/4), round(7*Width/10), round(2*Height/4),
                  round(5*Width/10), round(1*Height/4), round(6*Width/10), round(2*Height/4));
             MoveTo(round(6*Width/10)-1, round(2*Height/4));
             LineTo(round(9*Width/10)+1, round(2*Height/4));
             Arc( round(8*Width/10), round(2*Height/4), round(10*Width/10), round(4*Height/4),
                  round(10*Width/10), round(3*Height/4), round(9*Width/10), round(2*Height/4));
         end;
    end;
  end;
end;


procedure TAccolade.SetEpaisseur(Value: Integer);
begin
  if Value <> FEpaisseur then
  begin
    FEpaisseur := Value;
    Refresh;
  end;
end;

procedure TAccolade.SetOrientation(Value: TAOrientation);
begin
  if Value <> FOrientation then
  begin
    FOrientation := Value;
    Refresh;
  end;
end;

end.
